@@ -1,10 +1,7 @@
 # __init__.py
-versionnumber = "0.0.0.7"
 
 from .Core import loading_bar # Loading Bar Function
 from .Core import new_line # New Line Function
 from .Core import colored_text # Colored Text Function
 from .Core import generatekey # Generate Key Function
-from .Core import enhancedloading_bar # Enhanced Loading Bar
-from .Core import cls # Clear Screen Function
-from .Core import version # Version Variable
\ No newline at end of file
+from .Core import enhancedloading_bar # Enhanced Loading Bar
\ No newline at end of file
